@@ -22,6 +22,7 @@ import java.io.FileInputStream;
 import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.io.PrintWriter;
+import java.text.MessageFormat;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashMap;
@@ -29,7 +30,6 @@ import java.util.Iterator;
 import java.util.Properties;
 import java.util.ResourceBundle;
 
-import org.dbdoclet.service.MessageServices;
 import org.dbdoclet.service.ResourceServices;
 
 /**
@@ -266,7 +266,7 @@ public class OptionList implements Iterable<Option<?>> {
 
 		if (option == null) {
 
-			String msg = MessageServices.format(
+			String msg = MessageFormat.format(
 					ResourceServices.getString(res, "C_ERROR_OPTION_UNKNOWN"),
 					name);
 			throw new OptionException(msg);
@@ -288,7 +288,7 @@ public class OptionList implements Iterable<Option<?>> {
 			return (BooleanOption) option;
 		} else {
 
-			String msg = MessageServices.format(ResourceServices.getString(res,
+			String msg = MessageFormat.format(ResourceServices.getString(res,
 					"C_ERROR_OPTION_INVALID_TYPE"), name, "boolean", option
 					.getClass().getName());
 			throw new OptionException(msg);
@@ -311,7 +311,7 @@ public class OptionList implements Iterable<Option<?>> {
 
 			Option<?> existing = findExistingOption(option);
 
-			throw new OptionException(MessageServices.format(ResourceServices
+			throw new OptionException(MessageFormat.format(ResourceServices
 					.getString(res, "C_ERROR_OPTION_ALREADY_IN_USE"), option
 					.getFQName(), existing.getFQName()));
 
@@ -426,7 +426,7 @@ public class OptionList implements Iterable<Option<?>> {
 		Option<?> opt = optMap.get(name);
 
 		if (opt != null && opt.equals(option) == false) {
-			throw new OptionException(MessageServices.format(ResourceServices
+			throw new OptionException(MessageFormat.format(ResourceServices
 					.getString(res, "C_ERROR_OPTION_ALREADY_IN_USE"), name));
 
 		}
@@ -482,7 +482,7 @@ public class OptionList implements Iterable<Option<?>> {
 					option = deprecatedPropertiesMap.get(name);
 
 					if (option != null) {
-						buffer += MessageServices.format(ResourceServices
+						buffer += MessageFormat.format(ResourceServices
 								.getString(res, "C_WARN_PROPERTY_DEPRECATED"),
 								name, option.getPropertyName())
 								+ "\n";
@@ -513,7 +513,7 @@ public class OptionList implements Iterable<Option<?>> {
 
 				if (option == null) {
 
-					buffer += MessageServices.format(ResourceServices
+					buffer += MessageFormat.format(ResourceServices
 							.getString(res, "C_ERROR_PROPERTY_UNKNOWN"), name)
 							+ "\n";
 					continue;
@@ -590,7 +590,7 @@ public class OptionList implements Iterable<Option<?>> {
 			index = searchArgs(argList, option);
 
 			if (index == -1 && option.isRequired()) {
-				buffer += MessageServices
+				buffer += MessageFormat
 						.format(ResourceServices.getString(res,
 								"C_ERROR_OPTION_REQUIRED"), option
 								.getUniqueName())
@@ -606,7 +606,7 @@ public class OptionList implements Iterable<Option<?>> {
 
 					if (index == argList.size() - 1) {
 
-						buffer += MessageServices.format(ResourceServices
+						buffer += MessageFormat.format(ResourceServices
 								.getString(res, "C_ERROR_OPTION_NEEDS_ARG"),
 								option.getUniqueName())
 								+ "\n";
@@ -618,7 +618,7 @@ public class OptionList implements Iterable<Option<?>> {
 					arg = argList.get(index + 1);
 
 					if (arg.startsWith("-")) {
-						buffer += MessageServices.format(ResourceServices
+						buffer += MessageFormat.format(ResourceServices
 								.getString(res, "C_ERROR_OPTION_NEEDS_ARG"),
 								option.getUniqueName())
 								+ "\n";
@@ -634,7 +634,7 @@ public class OptionList implements Iterable<Option<?>> {
 
 						if (selopt.checkArgument(arg) == false) {
 
-							buffer += MessageServices.format(ResourceServices
+							buffer += MessageFormat.format(ResourceServices
 									.getString(res,
 											"C_ERROR_OPTION_INVALID_VALUE"),
 									option.getUniqueName(), arg, selopt
@@ -654,7 +654,7 @@ public class OptionList implements Iterable<Option<?>> {
 						PathOption pathopt = (PathOption) option;
 
 						if (pathopt.checkArgument(arg) == false) {
-							buffer += MessageServices.format(ResourceServices
+							buffer += MessageFormat.format(ResourceServices
 									.getString(res,
 											"C_ERROR_OPTION_INVALID_PATH"),
 									option.getUniqueName(), arg, pathopt
@@ -674,7 +674,7 @@ public class OptionList implements Iterable<Option<?>> {
 						FileOption fileopt = (FileOption) option;
 
 						if (fileopt.checkArgument(arg) == false) {
-							buffer += MessageServices.format(ResourceServices
+							buffer += MessageFormat.format(ResourceServices
 									.getString(res,
 											"C_ERROR_OPTION_INVALID_FILE"),
 									option.getUniqueName(), arg)
@@ -694,7 +694,7 @@ public class OptionList implements Iterable<Option<?>> {
 						DirectoryOption diropt = (DirectoryOption) option;
 
 						if (diropt.checkArgument(arg) == false) {
-							buffer += MessageServices
+							buffer += MessageFormat
 									.format(ResourceServices.getString(res,
 											"C_ERROR_OPTION_INVALID_DIRECTORY"),
 											option.getUniqueName(), arg)
@@ -769,7 +769,7 @@ public class OptionList implements Iterable<Option<?>> {
 
 				if (option.isUnique() && index != -1 && counter == 0) {
 
-					buffer += MessageServices.format(ResourceServices
+					buffer += MessageFormat.format(ResourceServices
 							.getString(res,
 									"C_ERROR_OPTION_WAS_FOUND_MORE_THAN_ONCE"),
 							option.getUniqueName())
@@ -789,7 +789,7 @@ public class OptionList implements Iterable<Option<?>> {
 				str += argList.get(i) + " ";
 			}
 
-			buffer += MessageServices.format(
+			buffer += MessageFormat.format(
 					ResourceServices.getString(res, "C_ERROR_OPTION_UNKNOWN"),
 					str) + "\n";
 		}
