@@ -32,6 +32,7 @@ import java.io.OutputStreamWriter;
 import java.io.PrintWriter;
 import java.net.FileNameMap;
 import java.net.URLConnection;
+import java.text.MessageFormat;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Iterator;
@@ -39,6 +40,8 @@ import java.util.Map;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import org.dbdoclet.CreatePathException;
 import org.dbdoclet.DeleteFileException;
 import org.dbdoclet.FileAccessDeniedException;
@@ -49,9 +52,8 @@ import org.dbdoclet.io.DirectoryFilter;
 import org.dbdoclet.io.EndsWithFilter;
 import org.dbdoclet.io.MimeType;
 import org.dbdoclet.io.StartsWithFilter;
-import org.dbdoclet.log.Logger;
-import org.dbdoclet.progress.ProgressListener;
 import org.dbdoclet.progress.ProgressEvent;
+import org.dbdoclet.progress.ProgressListener;
 import org.dbdoclet.template.TemplateTransformException;
 import org.dbdoclet.template.TemplateTransformer;
 
@@ -72,13 +74,14 @@ public class FileServices {
 
 	public static final String FSEP = System.getProperty("file.separator");
 
-	private static Logger logger = Logger.getLogger(FileServices.class);
+	private static Log logger = LogFactory.getLog(FileServices.class);
 
 	/** Verwende den StartsWith-Filter */
 	public static final int STARTS_WITH = 0;
 
-	public static final Pattern PATTERN_ABSOLUTE_WINDOWS_PATH = Pattern.compile("^([a-z,A-Z]:|/)/.*$");
-	
+	public static final Pattern PATTERN_ABSOLUTE_WINDOWS_PATH = Pattern
+			.compile("^([a-z,A-Z]:|/)/.*$");
+
 	/**
 	 * @see #appendFileName(String dir, String filename)
 	 */
@@ -592,7 +595,7 @@ public class FileServices {
 					logger.debug("Firing progress event.");
 
 					if (resourceString != null) {
-						msg = MessageServices.format(resourceString,
+						msg = MessageFormat.format(resourceString,
 								files[i].getPath(), destFile.getPath());
 					} else {
 						msg = files[i].getName();
@@ -1101,10 +1104,10 @@ public class FileServices {
 			String resourceString) throws IOException {
 		return delete(new File(path), listener, resourceString);
 	}
-	
+
 	/**
-	 * Die Methode <code>delete</code> <b>löscht</b> eine Datei oder ein Verzeichnis
-	 * und alle darin enthaltenen Dateien und Unterverzeichnisse.
+	 * Die Methode <code>delete</code> <b>löscht</b> eine Datei oder ein
+	 * Verzeichnis und alle darin enthaltenen Dateien und Unterverzeichnisse.
 	 */
 	public static int delete(File node, ProgressListener listener,
 			String resourceString) throws IOException {
@@ -1122,7 +1125,8 @@ public class FileServices {
 
 		if (node.exists() == false) {
 
-			logger.debug("Der Pfad " + node.getAbsolutePath() + " existiert nicht!");
+			logger.debug("Der Pfad " + node.getAbsolutePath()
+					+ " existiert nicht!");
 			return 0;
 		}
 
@@ -1192,8 +1196,7 @@ public class FileServices {
 				logger.debug("Firing progress event.");
 
 				if (resourceString != null) {
-					msg = MessageServices
-							.format(resourceString, node.getPath());
+					msg = MessageFormat.format(resourceString, node.getPath());
 				} else {
 					msg = node.getName();
 				}
@@ -1606,7 +1609,7 @@ public class FileServices {
 	 * Die Methode <code>getPathToken</code> liefert einen bestimmenten Teil
 	 * eines Pfades.
 	 * 
-	 * Der Pfad wird von <b>hinten</b> nach vorne beginnend mit der Ziffer 0
+	 * Der Pfad wird von <b>hinten</b> nach vorne beginnend mit der Ziffer 1
 	 * durchnummeriert.
 	 * 
 	 * @param path
@@ -1617,6 +1620,9 @@ public class FileServices {
 	 */
 	public static String getPathToken(String path, int index) {
 
+		if (index == 0)
+			return "";
+
 		if (path == null) {
 			throw new IllegalArgumentException(
 					"The argument path must not be null!");
@@ -1628,8 +1634,9 @@ public class FileServices {
 		}
 
 		String buffer = normalizePath(path);
+		buffer = StringServices.chop(buffer, "/");
 
-		// logger.debug("buffer = " + buffer);
+		logger.debug("buffer = " + buffer);
 
 		int indexStart = buffer.length();
 		int indexEnd = indexStart;
@@ -1639,15 +1646,15 @@ public class FileServices {
 			indexEnd = indexStart;
 			indexStart = buffer.lastIndexOf('/', indexStart - 1);
 
-			// logger.debug("start = " + indexStart + ", end = " + indexEnd);
+			logger.debug("start = " + indexStart + ", end = " + indexEnd);
 
 			if (indexStart == -1) {
 				return null;
 			}
 		}
 
-		String token = path.substring(indexStart + 1, indexEnd);
-		// logger.debug("path token [" + index + "] = '" + token + "'.");
+		String token = buffer.substring(indexStart + 1, indexEnd);
+		logger.debug("path token [" + index + "] = '" + token + "'.");
 
 		return token;
 	}
@@ -2163,6 +2170,7 @@ public class FileServices {
 		if (fileLength > Integer.MAX_VALUE) {
 
 			logger.error("The file is too big (>" + Integer.MAX_VALUE + ")!");
+			fis.close();
 			return null;
 		}
 
@@ -2344,7 +2352,7 @@ public class FileServices {
 		String str;
 
 		File fromParent = from;
-		
+
 		if (fromParent.isFile() == true) {
 			fromParent = fromParent.getParentFile();
 		}
@@ -2767,23 +2775,26 @@ public class FileServices {
 
 		return winPath;
 	}
-	
+
 	/**
-	 * This method corrects the path regarding the used operating system. Windows "\" and Linux "/"
-	 * @param in the string representing the path
+	 * This method corrects the path regarding the used operating system.
+	 * Windows "\" and Linux "/"
+	 * 
+	 * @param in
+	 *            the string representing the path
 	 * @return out the corrected string representing the path
 	 */
 	public static String correctPathSeperator(String in) {
-	    String os = System.getProperty("os.name");
-	    
-	    in = FileServices.normalizePath(in);
-	    if (os.toLowerCase().contains("windows")) {
-		in = toWindowsPath(in);
+		String os = System.getProperty("os.name");
+
+		in = FileServices.normalizePath(in);
+		if (os.toLowerCase().contains("windows")) {
+			in = toWindowsPath(in);
+			return in;
+		}
+
 		return in;
-	    }
-	    
-	    return in;
-	    
+
 	}
 
 	public static void traverse(File dir, FileVisitor visitor) {
