@@ -21,6 +21,8 @@ package org.dbdoclet.service;
 import java.io.File;
 import java.util.List;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import org.dbdoclet.Sfv;
 
 /**
@@ -33,6 +35,12 @@ import org.dbdoclet.Sfv;
  */
 public class StringServices {
 
+	public static final Log logger = LogFactory.getLog(StringServices.class);
+
+	public static final String ZERO_WIDTH_SPACE = "\u200b";
+	public static final String SIX_PER_EM_SPACE = "\u2006";
+	public static final String SOFT_HYPHEN = "\u00ad";
+
 	/**
 	 * Die Methode <code>replace</code> ersetzt alle Vorkomnisse eines
 	 * bestimmten Musters durch eine Zeichenkette.
@@ -519,8 +527,9 @@ public class StringServices {
 	}
 
 	/**
-	 * Die Methode <code>chop</code> bzw. <code>cutSuffix</code> schneidet die mit <code>suffix</code>
-	 * angegebene Zeichenkette vom Ende der Zeichenkette <code>suffix</code> ab.
+	 * Die Methode <code>chop</code> bzw. <code>cutSuffix</code> schneidet die
+	 * mit <code>suffix</code> angegebene Zeichenkette vom Ende der Zeichenkette
+	 * <code>suffix</code> ab.
 	 * 
 	 * @param text
 	 *            <code>String</code>
@@ -530,6 +539,11 @@ public class StringServices {
 	 */
 	public static String cutSuffix(String text, String suffix) {
 
+		if (suffix == null) {
+			logger.warn(String
+					.format("Can't cut off a null suffix (%s)!", text));
+			return text;
+		}
 		if (text == null) {
 			return null;
 		}
@@ -873,7 +887,7 @@ public class StringServices {
 		String[] tokens = { "/", "\\", "-" };
 
 		String wrapable = new String(str);
-		
+
 		for (String token : tokens) {
 
 			if (token == null || token.length() == 0) {
@@ -881,7 +895,8 @@ public class StringServices {
 			}
 
 			// zero width space
-			wrapable = StringServices.replace(wrapable, token, token + "\u200b");
+			wrapable = StringServices.replace(wrapable, token, token
+					+ ZERO_WIDTH_SPACE);
 		}
 
 		return wrapable;
@@ -940,25 +955,25 @@ public class StringServices {
 	public static String createBox(String text) {
 
 		StringBuilder buffer = new StringBuilder();
-		
+
 		buffer.append('\u2554');
 
 		for (int i = 0; i < text.length() + 2; i++) {
 			buffer.append('\u2550');
 		}
-		
+
 		buffer.append('\u2557');
 		buffer.append('\n');
 		buffer.append("\u2551 ");
 		buffer.append(text);
 		buffer.append(" \u2551\n");
-		
+
 		buffer.append('\u255A');
 
 		for (int i = 0; i < text.length() + 2; i++) {
 			buffer.append('\u2550');
 		}
-		
+
 		buffer.append('\u255D');
 		buffer.append('\n');
 
