@@ -25,8 +25,9 @@ import java.io.StringWriter;
 import java.util.ArrayList;
 import java.util.Iterator;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import org.dbdoclet.CanceledException;
-import org.dbdoclet.log.Logger;
 import org.dbdoclet.progress.ProgressEvent;
 import org.dbdoclet.progress.ProgressListener;
 import org.dbdoclet.progress.ProgressManager;
@@ -69,24 +70,24 @@ import org.w3c.dom.Text;
 public class DocBookTransformer {
 
 	public enum DocumentElementType {
-		ARTICLE, BOOK, OVERVIEW, PARAGRAPH, PART, REFERENCE, SECTION;
+		ARTICLE, BOOK, CHAPTER, OVERVIEW, PARAGRAPH, PART, REFERENCE, SECTION;
 	}
 
-	private static Logger logger = Logger.getLogger(DocBookTransformer.class);
+	private static Log logger = LogFactory.getLog(DocBookTransformer.class);
 
 	private DocBookTagFactory dbfactory;
 	private File destinationFile;
-	
+
 	/**
 	 * Einrückung für Debugging-Ausgaben
 	 */
 	private String indent = "";
-	
+
 	private final LinkManager linkManager;
 	public final ArrayList<ProgressListener> listeners = new ArrayList<ProgressListener>();
 	private DocumentElementType documentType = DocumentElementType.ARTICLE;
 	private Script script;
-	private ProgressManager pm;
+	private final ProgressManager pm;
 
 	public DocBookTransformer(File destinationFile) {
 
@@ -130,9 +131,9 @@ public class DocBookTransformer {
 
 		try {
 			htmlCode = FileServices.readToString(file, script.getTextParameter(
-					DBTConstants.SECTION_HTML,
-					DBTConstants.PARAM_HTML_SOURCE_ENCODING,
-					DBTConstants.DEFAULT_SOURCE_ENCODING));
+					DbtConstants.SECTION_HTML,
+					DbtConstants.PARAM_HTML_SOURCE_ENCODING,
+					DbtConstants.DEFAULT_SOURCE_ENCODING));
 			return convert(htmlCode, file);
 		} catch (IOException oops) {
 			throw new TrafoException(oops);
@@ -149,8 +150,8 @@ public class DocBookTransformer {
 			String buffer = convert(inFile);
 			FileServices.createParentDir(destinationFile);
 			FileServices.writeFromString(destinationFile, buffer, script
-					.getTextParameter(DBTConstants.SECTION_DOCBOOK,
-							DBTConstants.PARAM_DOCBOOK_DESTINATION_ENCODING, "UTF-8"));
+					.getTextParameter(DbtConstants.SECTION_DOCBOOK,
+							DbtConstants.PARAM_DOCBOOK_ENCODING, "UTF-8"));
 			return buffer;
 
 		} catch (IOException oops) {
@@ -167,7 +168,8 @@ public class DocBookTransformer {
 
 		try {
 
-			buffer = transformDocument(htmlCode, documentType, new TrafoResult());
+			buffer = transformDocument(htmlCode, documentType,
+					new TrafoResult());
 
 		} catch (TrafoException oops) {
 
@@ -241,30 +243,16 @@ public class DocBookTransformer {
 	}
 
 	public void setScript(Script script) {
-		
+
 		this.script = script;
 
 		if (script != null) {
 
-			String value = script.getTextParameter(DBTConstants.SECTION_DOCBOOK,
-					DBTConstants.PARAM_DOCBOOK_DOCUMENT_ELEMENT, "article");
-
-			if (value.equalsIgnoreCase("part")) {
-				documentType = DocBookTransformer.DocumentElementType.PART;
-			} else if (value.equalsIgnoreCase("book")) {
-				documentType = DocBookTransformer.DocumentElementType.BOOK;
-			} else {
-				documentType = DocBookTransformer.DocumentElementType.ARTICLE;
-			}
-
-//			scriptManager.initDocBookScriptMap(script.getTextParameter(
-//					DBTConstants.SECTION_GROOVY,
-//					DBTConstants.PARAM_GROOVY_DOCBOOK_SCRIPT_PATH, "./scripts/docbook/"));
-//
-//			scriptManager.initHtmlScriptMap(script.getTextParameter(
-//					DBTConstants.SECTION_GROOVY,
-//					DBTConstants.PARAM_GROOVY_HTML_SCRIPT_PATH, "./scripts/html/"));
+			String value = script.getTextParameter(
+					DbtConstants.SECTION_DOCBOOK,
+					DbtConstants.PARAM_DOCBOOK_DOCUMENT_ELEMENT, "article");
 
+			documentType = DocumentElementType.valueOf(value.toUpperCase());
 		}
 	}
 
@@ -281,8 +269,7 @@ public class DocBookTransformer {
 	public NodeImpl transform(NodeImpl htmlRoot, NodeImpl parent,
 			TrafoResult result) throws Exception {
 
-		logger.info("Starting transformation...");
-		logger.debug5("-> transform(NodeImpl, NodeImpl, TrafoResult) "
+		logger.debug("-> transform(NodeImpl, NodeImpl, TrafoResult) "
 				+ htmlRoot);
 
 		if (htmlRoot == null) {
@@ -295,7 +282,7 @@ public class DocBookTransformer {
 		}
 
 		TextParam excludeParam = (TextParam) script.getParameter(
-				DBTConstants.SECTION_HTML, DBTConstants.PARAM_HTML_EXCLUDE);
+				DbtConstants.SECTION_HTML, DbtConstants.PARAM_HTML_EXCLUDE);
 
 		if (excludeParam != null) {
 
@@ -344,13 +331,14 @@ public class DocBookTransformer {
 			root = root.getTrafoParentNode();
 		}
 
-		// logger.debug5("Edit - DocBook XML Tree =\n" + root.treeView());
+		// logger.debug("Edit - DocBook XML Tree =\n" + root.treeView());
 		pm.nextStage();
 		nodeCounter = new NodeCountVisitor(listeners);
 		pm.fireProgressEvent(new ProgressEvent("Postprocess stage 1...", false));
 		root.traverse(nodeCounter);
 		pm.setProgressMaximum(nodeCounter.getNumberOfNodes());
-		PostprocessStage1 postprocessStage1 = new PostprocessStage1(listeners);
+		PostprocessStage1 postprocessStage1 = new PostprocessStage1(dbfactory,
+				script, listeners);
 		root.traverse(postprocessStage1);
 		postprocessStage1.finish();
 
@@ -366,19 +354,18 @@ public class DocBookTransformer {
 		new PostprocessStage3(dbfactory, postprocessStage1.getSubtables())
 				.process();
 
-//		pm.nextStage();
-//		if (scriptManager.docbookScriptsAvailable()) {
-//			pm.fireProgressEvent(new ProgressEvent(
-//					"Customizing DocBook tree...", false));
-//			root.traverse(nodeCounter.reset());
-//			pm.setProgressMaximum(nodeCounter.getNumberOfNodes());
-//			customizeDocBook((Element) root);
-//		}
+		// pm.nextStage();
+		// if (scriptManager.docbookScriptsAvailable()) {
+		// pm.fireProgressEvent(new ProgressEvent(
+		// "Customizing DocBook tree...", false));
+		// root.traverse(nodeCounter.reset());
+		// pm.setProgressMaximum(nodeCounter.getNumberOfNodes());
+		// customizeDocBook((Element) root);
+		// }
+
+		boolean addIndex = script.isParameterOn(DbtConstants.SECTION_DOCBOOK,
+				DbtConstants.PARAM_DOCBOOK_ADD_INDEX, false);
 
-		boolean addIndex = script.isParameterEnabled(
-				DBTConstants.SECTION_DOCBOOK, DBTConstants.PARAM_DOCBOOK_ADD_INDEX,
-				false);
-			
 		if (addIndex == true) {
 			root.appendChild(dbfactory.createIndex());
 		}
@@ -412,12 +399,12 @@ public class DocBookTransformer {
 				throw new TrafoException("Transformation returned null!");
 			}
 
-			logger.debug5("Transformer out=" + xml);
+			logger.debug("Transformer out=" + xml);
 
 			String destinationEncoding = script.getTextParameter(
-					DBTConstants.SECTION_DOCBOOK,
-					DBTConstants.PARAM_DOCBOOK_DESTINATION_ENCODING,
-					DBTConstants.DEFAULT_DESTINATION_ENCODING);
+					DbtConstants.SECTION_DOCBOOK,
+					DbtConstants.PARAM_DOCBOOK_ENCODING,
+					DbtConstants.DEFAULT_DESTINATION_ENCODING);
 			byte[] data = XmlServices.validate(xml, destinationEncoding);
 			result.setData(data);
 
@@ -451,11 +438,12 @@ public class DocBookTransformer {
 	public NodeImpl transform(String buffer, NodeImpl parent,
 			HtmlElement skipTo, TrafoResult result) throws Exception {
 
-		logger.debug5("-> transform(String, NodeImpl, HtmlElement, TrafoResult)");
+		logger.debug("-> transform(String, NodeImpl, HtmlElement, TrafoResult)");
 
 		HtmlParser parser = new HtmlParser();
 
-		if (documentType == DocumentElementType.SECTION
+		if (documentType == DocumentElementType.CHAPTER
+				|| documentType == DocumentElementType.SECTION
 				|| documentType == DocumentElementType.PARAGRAPH
 				|| documentType == DocumentElementType.OVERVIEW) {
 			parser.setCodeContext(HtmlParser.CONTEXT_BODY);
@@ -469,15 +457,15 @@ public class DocBookTransformer {
 			htmlRoot = parser.parseFragment(buffer);
 		}
 
-		// logger.debug5(((HtmlFragment) htmlRoot).toXML());
-		// logger.debug5("HTML Tree =\n" + ((TrafoNode) htmlRoot).treeView());
+		// logger.debug(((HtmlFragment) htmlRoot).toXML());
+		// logger.debug("HTML Tree =\n" + ((TrafoNode) htmlRoot).treeView());
 
 		if (htmlRoot == null) {
 			return null;
 		}
 
 		NodeImpl rc = transform(htmlRoot, parent, result);
-		logger.debug5("<- transform(String, NodeImpl, HtmlElement, TrafoResult)");
+		logger.debug("<- transform(String, NodeImpl, HtmlElement, TrafoResult)");
 		return rc;
 	}
 
@@ -485,7 +473,11 @@ public class DocBookTransformer {
 			DocumentElementType documentType, TrafoResult result)
 			throws TrafoException {
 
-		logger.debug5("-> transformDocument");
+		logger.debug("-> transformDocument");
+
+		if (script == null) {
+			script = new Script();
+		}
 
 		try {
 
@@ -510,8 +502,8 @@ public class DocBookTransformer {
 			documentElement.removeAttribute("xmlns");
 
 			String language = script.getTextParameter(
-					DBTConstants.SECTION_DOCBOOK, DBTConstants.PARAM_DOCBOOK_LANGUAGE,
-					null);
+					DbtConstants.SECTION_DOCBOOK,
+					DbtConstants.PARAM_DOCBOOK_LANGUAGE, null);
 
 			if (language == null) {
 				lang = detectLanguage(documentElement);
@@ -519,31 +511,35 @@ public class DocBookTransformer {
 				lang = language;
 			}
 
-//			pm.nextStage();
-//			if (scriptManager.htmlScriptsAvailable()) {
-//				pm.setProgressMaximum(elemCount);
-//				customizeHtml(documentElement);
-//			}
-//
+			// pm.nextStage();
+			// if (scriptManager.htmlScriptsAvailable()) {
+			// pm.setProgressMaximum(elemCount);
+			// customizeHtml(documentElement);
+			// }
+			//
 			DocBookDocument doc = new DocBookDocument();
 			doc.setXmlEncoding(script.getTextParameter(
-					DBTConstants.SECTION_DOCBOOK,
-					DBTConstants.PARAM_DOCBOOK_DESTINATION_ENCODING,
-					DBTConstants.DEFAULT_DESTINATION_ENCODING));
+					DbtConstants.SECTION_DOCBOOK,
+					DbtConstants.PARAM_DOCBOOK_ENCODING,
+					DbtConstants.DEFAULT_DESTINATION_ENCODING));
 
 			DocBookTagFactory dbf = getTagFactory();
 			DocBookElement rootElement;
 
 			this.documentType = documentType;
-			
+
 			if (documentType == DocumentElementType.BOOK) {
 				rootElement = dbf.createBook();
 			} else if (documentType == DocumentElementType.REFERENCE) {
 				rootElement = dbf.createReference();
+			} else if (documentType == DocumentElementType.PART) {
+				rootElement = dbf.createPart();
+			} else if (documentType == DocumentElementType.CHAPTER) {
+				rootElement = dbf.createChapter();
 			} else if (documentType == DocumentElementType.SECTION) {
 				rootElement = dbf.createSection();
 			} else if (documentType == DocumentElementType.PARAGRAPH) {
-				rootElement = dbf.createSection();
+				rootElement = dbf.createPara();
 			} else {
 				rootElement = dbf.createArticle();
 			}
@@ -558,8 +554,8 @@ public class DocBookTransformer {
 			rootElement.appendChild(info);
 
 			String title = script.getTextParameter(
-					DBTConstants.SECTION_DOCBOOK, DBTConstants.PARAM_DOCBOOK_TITLE,
-					null);
+					DbtConstants.SECTION_DOCBOOK,
+					DbtConstants.PARAM_DOCBOOK_TITLE, null);
 
 			if (title != null && title.trim().length() > 0) {
 
@@ -567,17 +563,16 @@ public class DocBookTransformer {
 
 			} else {
 
-				HtmlElement elem = (HtmlElement) XPathServices.getNode(
-						(Document) htmlDoc, "/html/head/title");
+				HtmlElement elem = (HtmlElement) XPathServices.getNode(htmlDoc,
+						"/html/head/title");
 
 				if (elem == null) {
 
 					for (int i = 1; i <= 6; i++) {
 
 						if (elem == null) {
-							elem = (HtmlElement) XPathServices.getNode(
-									(Document) htmlDoc, "/html/body/h" + i
-											+ "[1]");
+							elem = (HtmlElement) XPathServices.getNode(htmlDoc,
+									"/html/body/h" + i + "[1]");
 						}
 					}
 				}
@@ -588,8 +583,8 @@ public class DocBookTransformer {
 
 				} else {
 
-					Text text = (Text) XPathServices.getNode(
-							(Document) htmlDoc, "//text()[1]");
+					Text text = (Text) XPathServices.getNode(htmlDoc,
+							"//text()[1]");
 
 					if (text != null) {
 						info.appendChild(dbf.createTitle(text.getData()));
@@ -606,7 +601,7 @@ public class DocBookTransformer {
 			transform(documentElement, rootElement, result);
 			StringWriter buffer = serialize(doc);
 
-			logger.debug5("<- transformDocument");
+			logger.debug("<- transformDocument");
 			return buffer.toString();
 
 		} catch (TrafoException oops) {
@@ -624,7 +619,15 @@ public class DocBookTransformer {
 	public String transformFragment(String htmlCode, TrafoResult result)
 			throws TrafoException {
 
-		logger.debug5("-> transformFragment " + htmlCode);
+		logger.debug("-> transformFragment " + htmlCode);
+
+		if (script == null) {
+			script = new Script();
+		}
+
+		script.setEnabled(DbtConstants.SECTION_DOCBOOK,
+				DbtConstants.PARAM_DOCBOOK_ADD_INDEX, false);
+
 		try {
 
 			HtmlParser parser = new HtmlParser();
@@ -639,12 +642,12 @@ public class DocBookTransformer {
 				throw new TrafoException("Couldn't find a html fragment!");
 			}
 
-			logger.debug5("transform");
+			logger.debug("transform");
 			DocBookFragment parent = new DocBookFragment();
 			NodeImpl elem = transform(htmlRoot, parent, result);
 			StringWriter buffer = serialize(elem);
 
-			logger.debug5("<- transformFragment");
+			logger.debug("<- transformFragment");
 
 			return buffer.toString();
 
@@ -709,28 +712,27 @@ public class DocBookTransformer {
 	}
 
 	/**
-	 * The method <code>edit</code> is reponsible for the transformation of the HTML document tree into an DocBook
-	 * document tree.
+	 * The method <code>edit</code> is reponsible for the transformation of the
+	 * HTML document tree into an DocBook document tree.
 	 * 
 	 * @param htmlNode
 	 *            a <code>Node</code> value
 	 * @param dbParent
 	 *            a <code>DocBookElement</code> value
 	 * 
-	 * @return a <code>Element</code>. The root node of the created DocBook document tree.
+	 * @return a <code>Element</code>. The root node of the created DocBook
+	 *         document tree.
 	 */
 	private DocBookElement edit(NodeImpl htmlNode, DocBookElement dbParent) {
 
-		logger.debug5("-> edit " + htmlNode);
+		logger.debug("-> edit " + htmlNode);
 
 		if (htmlNode == null) {
-
 			logger.error("[DocBookDoclet.edit] - Parameter node is null!");
 			return null;
 		}
 
 		if (dbParent == null) {
-
 			logger.error("[DocBookDoclet.edit] - Parameter dbParent is null!");
 			return null;
 		}
@@ -755,12 +757,12 @@ public class DocBookTransformer {
 
 		int index = 0;
 
-		logger.debug5(indent
+		logger.debug(indent
 				+ "\n>>>==================================================");
-		logger.debug5(indent + " HTML Vaterelement " + htmlNode + ".");
-		logger.debug5(indent + " DocBook Vaterelement " + dbParent + ".");
+		logger.debug(indent + " HTML Vaterelement " + htmlNode + ".");
+		logger.debug(indent + " DocBook Vaterelement " + dbParent + ".");
 
-		indent += "+";
+		indent += ".";
 
 		while (iterator.hasNext()) {
 
@@ -771,7 +773,7 @@ public class DocBookTransformer {
 			pm.fireProgressEvent(new ProgressEvent("Transforming "
 					+ child.toString()));
 
-			logger.debug5(indent + "HTML element is " + child + ".");
+			logger.debug(indent + " HTML element is " + child + ".");
 
 			dbElement = dbParent;
 			doTraverse = true;
@@ -794,13 +796,12 @@ public class DocBookTransformer {
 
 						editor = EditorFactory.getCommentEditor();
 
-						logger.debug5(indent
-								+ " Vor der Kommentarbearbeitung: " + child
-								+ ".\n");
+						logger.debug(indent + " Vor der Kommentarbearbeitung: "
+								+ child + ".\n");
 
 						values = editor.edit(values);
 
-						logger.debug5(indent
+						logger.debug(indent
 								+ " Nach der Kommentarbearbeitung: " + child
 								+ ".\n");
 						dbParent = values.getParent();
@@ -823,14 +824,14 @@ public class DocBookTransformer {
 					}
 
 				} catch (EditorException oops) {
-					logger.debug5(indent + "EditorException "
+					logger.debug(indent + " EditorException "
 							+ oops.getMessage());
 				}
 			}
 
 			if (child instanceof TextImpl) {
 
-				// logger.debug5("Text='" + ((Text) child).getText() + "'");
+				logger.debug("Text='" + ((Text) child).toString() + "'");
 
 				try {
 
@@ -846,11 +847,11 @@ public class DocBookTransformer {
 
 					editor = EditorFactory.getTextEditor();
 
-					logger.debug5(indent + " Vor der Textbearbeitung: " + child
+					logger.debug(indent + " Vor der Textbearbeitung: " + child
 							+ ".\n");
 					values = editor.edit(values);
-					logger.debug5(indent + " Nach der Textbearbeitung: "
-							+ child + ".\n");
+					logger.debug(indent + " Nach der Textbearbeitung: " + child
+							+ ".\n");
 
 					dbParent = values.getParent();
 
@@ -866,7 +867,7 @@ public class DocBookTransformer {
 
 				} catch (EditorException oops) {
 
-					logger.debug5(indent + "EditorException "
+					logger.debug(indent + "EditorException "
 							+ oops.getMessage());
 				}
 			}
@@ -880,7 +881,7 @@ public class DocBookTransformer {
 					if (!checkCodeContext(htmlElement)) {
 
 						logger.warn(indent
-								+ "Element is not allowed in this code context("
+								+ " Element is not allowed in this code context("
 								+ documentType + ") '" + htmlElement + "'!");
 
 						continue;
@@ -888,7 +889,7 @@ public class DocBookTransformer {
 
 					editor = EditorFactory.getChildEditor(htmlElement);
 
-					logger.debug5("Setting editor values.");
+					logger.debug("Setting editor values.");
 
 					EditorInstruction values = new EditorInstruction();
 
@@ -900,7 +901,7 @@ public class DocBookTransformer {
 					values.setCharacterDataNode(null);
 					values.setTransformer(this);
 
-					logger.debug5(indent + " Vor der Transformation: " + child
+					logger.debug(indent + " Vor der Transformation: " + child
 							+ ".\n" + "Editor " + editor + "\n" + values);
 
 					if (child.getTransformInstruction() != null) {
@@ -933,9 +934,10 @@ public class DocBookTransformer {
 					}
 
 					dbElement = values.getCurrent();
-					// editor.copyCommonAttributes((HtmlElement) child, dbElement);
+					// editor.copyCommonAttributes((HtmlElement) child,
+					// dbElement);
 
-					logger.debug5(indent + " Nach der Transformation: " + child
+					logger.debug(indent + " Nach der Transformation: " + child
 							+ ".\n" + "Editor " + editor + "\n" + values);
 
 					doTraverse = values.doTraverse();
@@ -954,11 +956,11 @@ public class DocBookTransformer {
 
 				} catch (EditorFactoryException oops) {
 
-					logger.debug5("EditorFactoryException " + oops.getMessage());
+					logger.debug("EditorFactoryException " + oops.getMessage());
 
 				} catch (EditorException oops) {
 
-					logger.debug5("EditorException " + oops.getMessage());
+					logger.debug("EditorException " + oops.getMessage());
 				}
 			}
 
@@ -966,7 +968,7 @@ public class DocBookTransformer {
 
 				dbChildParent = edit(child, dbElement);
 
-				logger.debug5(indent
+				logger.debug(indent
 						+ "\n<<<==================================================");
 
 				if (doIgnore == true) {
@@ -985,17 +987,17 @@ public class DocBookTransformer {
 				// System.out.println("doTraverse == false " + num + "  ");
 			}
 
-			logger.debug5(indent + "[Teilbaum bearbeitet] HTML: " + child
+			logger.debug(indent + "[Teilbaum bearbeitet] HTML: " + child
 					+ ", DocBook: " + dbElement + ", Vater: " + dbParent);
 			dbElement.closed();
 
 			if (dbParent != dbOldParent) {
 
-				logger.debug5(indent + "Parent changed. Old parent was "
+				logger.debug(indent + "Parent changed. Old parent was "
 						+ dbOldParent + ". New parent is " + dbParent + ".");
 
 				dbelem = dbOldParent;
-				logger.debug5(indent + "Closing old parent " + dbelem
+				logger.debug(indent + "Closing old parent " + dbelem
 						+ ". HTML Element is " + child + ".");
 				dbelem.closed();
 				dbelem.isNew(false);
@@ -1010,12 +1012,12 @@ public class DocBookTransformer {
 			indent = indent.substring(0, indent.length() - 2);
 		}
 
-		logger.debug5(indent + "[Vaterknoten bearbeitet] HTML: " + child
+		logger.debug(indent + "[Vaterknoten bearbeitet] HTML: " + child
 				+ ", Vaterknoten: " + dbParent);
 		dbParent.closed();
 		dbParent.isNew(false);
 
-		logger.debug5("<- edit ");
+		logger.debug("<- edit ");
 		return dbParent;
 	}
 
