@@ -18,7 +18,7 @@
  */
 package org.dbdoclet.trafo.html.docbook.editor;
 
-import org.dbdoclet.trafo.html.docbook.DBTConstants;
+import org.dbdoclet.trafo.html.docbook.DbtConstants;
 import org.dbdoclet.trafo.tag.docbook.Emphasis;
 
 public class UEditor extends EmEditor {
@@ -31,7 +31,7 @@ public class UEditor extends EmEditor {
         Emphasis emphasis = getEmphasis();
         
 		if (emphasis != null) {
-            emphasis.setRole(DBTConstants.DEFAULT_EMPHASIS_ROLE_UNDERLINE);
+            emphasis.setRole(DbtConstants.DEFAULT_EMPHASIS_ROLE_UNDERLINE);
         }
         
         return evo;
