@@ -20,43 +20,43 @@ package org.dbdoclet.trafo.tag.html;
 
 import java.util.HashMap;
 
-
 public class Meta extends ReplaceElement {
 
-    private static final String tag = "meta";
-    private static HashMap<String, HashMap<String, String>> validParentMap;
+	private static final String tag = "meta";
+	private static HashMap<String, HashMap<String, String>> validParentMap;
 
-    static {
+	static {
 
-        validParentMap = new HashMap<String, HashMap<String, String>>();
-        validParentMap.put(Head.getTag(), HtmlElement.getAttributeMap());
-    }
+		validParentMap = new HashMap<String, HashMap<String, String>>();
+		validParentMap.put(Head.getTag(), HtmlElement.getAttributeMap());
+	}
 
-    public Meta() {
+	public Meta() {
 
-        setNodeName("meta");
-        setFormatType(FORMAT_CONTENT);
-        isEmpty(true);
-    }
+		setNodeName("meta");
+		setFormatType(FORMAT_CONTENT);
+		isEmpty(true);
+	}
 
-    @Override
-	public void init() {
+	public static String getTag() {
+		return tag;
+	}
 
-    }
-
-    public static String getTag() {
-
-        return tag;
-    }
-
-    @Override
+	@Override
 	public boolean validate() {
 
-        if (validate(validParentMap)) {
+		if (validate(validParentMap)) {
+			return true;
+		}
 
-            return true;
-        }
+		return false;
+	}
 
-        return false;
-    }
+	public String getName() {
+		return getAttribute("name");
+	}
+
+	public String getContent() {
+		return getAttribute("content");
+	}
 }
