@@ -26,11 +26,12 @@ import java.io.UnsupportedEncodingException;
 import org.dbdoclet.progress.ProgressListener;
 import org.dbdoclet.progress.ProgressEvent;
 import org.dbdoclet.progress.ProgressManager;
-import org.dbdoclet.log.Logger;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+
 
-@SuppressWarnings("all")
 public class XmlTokenizer/*@bgen(jjtree)*/implements XmlTokenizerTreeConstants, XmlTokenizerConstants {/*@bgen(jjtree)*/
-  protected JJTXmlTokenizerState jjtree = new JJTXmlTokenizerState();private static Logger logger = Logger.getLogger(XmlTokenizer.class);
+  protected JJTXmlTokenizerState jjtree = new JJTXmlTokenizerState();private static Log logger = LogFactory.getLog(XmlTokenizer.class);
 
   private ArrayList<org.dbdoclet.trafo.tokenizer.Token> tokenList;
   private ArrayList<ProgressListener> listeners;
@@ -183,8 +184,9 @@ public class XmlTokenizer/*@bgen(jjtree)*/implements XmlTokenizerTreeConstants,
         }
         jj_consume_token(TAG_END);
       } catch (Throwable oops) {
-    logger.fatal(String.format("Invalid attributes in Element %s line %d column %d",
-                         token.getTagName(), token.getLine(), token.getColumn()), oops);
+    logger.warn(String.format("Invalid attributes in Element %s line %d column %d",
+                         token.getTagName(), token.getLine(), token.getColumn()));
+    logger.warn(oops.getMessage());
     Token t = skipTo(DEFAULT, DEFAULT, token.toString(), TAG_END, TAG_START);
     token.setValue("&lt;" + token.getTagName() + toAttributesAsText(attributeMap) + t.image);
     {if (true) return;}
@@ -317,13 +319,19 @@ public class XmlTokenizer/*@bgen(jjtree)*/implements XmlTokenizerTreeConstants,
  /*@bgen(jjtree) attrName */
   SimpleNode jjtn000 = new SimpleNode(JJTATTRNAME);
   boolean jjtc000 = true;
-  jjtree.openNodeScope(jjtn000);Token t;
+  jjtree.openNodeScope(jjtn000);Token token = null;
     try {
-      t = jj_consume_token(NCNAME);
-    jjtree.closeNodeScope(jjtn000, true);
-    jjtc000 = false;
-    // System.out.println(t.image);
-    {if (true) return t;}
+      try {
+        token = jj_consume_token(NCNAME);
+    // System.out.println(token.image);
+    {if (true) return token;}
+      } catch (Throwable oops) {
+    logger.warn(String.format("Invalid attributes in Element %s line %d column %d",
+                         token.image, token.beginLine, token.beginColumn));
+        logger.warn(oops.getMessage());
+
+        {if (true) return skipTo(DEFAULT, TAG_CONTEXT, "", TAG_END, QUOTE);}
+      }
     } finally {
     if (jjtc000) {
       jjtree.closeNodeScope(jjtn000, true);
@@ -336,25 +344,27 @@ public class XmlTokenizer/*@bgen(jjtree)*/implements XmlTokenizerTreeConstants,
  /*@bgen(jjtree) attrValue */
   SimpleNode jjtn000 = new SimpleNode(JJTATTRVALUE);
   boolean jjtc000 = true;
-  jjtree.openNodeScope(jjtn000);Token t = null;
+  jjtree.openNodeScope(jjtn000);Token token = null;
     try {
       try {
         switch ((jj_ntk==-1)?jj_ntk():jj_ntk) {
         case VALUE:
-          t = jj_consume_token(VALUE);
+          token = jj_consume_token(VALUE);
           break;
         case NCNAME:
-          t = jj_consume_token(NCNAME);
+          token = jj_consume_token(NCNAME);
           break;
         default:
           jj_la1[7] = jj_gen;
           jj_consume_token(-1);
           throw new ParseException();
         }
-        {if (true) return t;}
+        {if (true) return token;}
       } catch (Throwable oops) {
-    oops.printStackTrace();
-        {if (true) return skipTo(DEFAULT, TAG_CONTEXT, "", QUOTE);}
+    logger.warn(String.format("Invalid attributes in Element %s line %d column %d",
+                         token.image, token.beginLine, token.beginColumn));
+    logger.warn(oops.getMessage());
+        {if (true) return skipTo(DEFAULT, TAG_CONTEXT, "", TAG_END, QUOTE);}
       }
     } finally {
     if (jjtc000) {
