@@ -24,10 +24,10 @@ import java.io.UnsupportedEncodingException;
 import org.dbdoclet.progress.ProgressListener;
 import org.dbdoclet.progress.ProgressEvent;
 import org.dbdoclet.progress.ProgressManager;
-import org.dbdoclet.log.Logger;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 
 /** Token Manager. */
-@SuppressWarnings("all")
 public class XmlTokenizerTokenManager implements XmlTokenizerConstants
 {
 
