@@ -57,8 +57,9 @@ import javax.xml.transform.stream.StreamSource;
 import javax.xml.validation.Schema;
 import javax.xml.validation.SchemaFactory;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import org.apache.xml.resolver.tools.CatalogResolver;
-import org.dbdoclet.log.Logger;
 import org.dbdoclet.service.FileServices;
 import org.dbdoclet.service.ReplaceServices;
 import org.dbdoclet.service.StringServices;
@@ -92,10 +93,9 @@ public class XmlServices {
 	private static final Pattern encPattern = Pattern
 			.compile("^(?i).*<\\?xml\\s*.*encoding=['\"](.*)['\"].*\\?>.*$");
 
-	private static Logger logger = Logger.getLogger(XmlServices.class);
+	private static Log logger = LogFactory.getLog(XmlServices.class);
 	private static final Pattern startsWithDigitPattern = Pattern
 			.compile("^[0-9].*$");
-	/** Der Standardausgabekanal */
 
 	static {
 		System.setProperty("xml.catalog.ignoreMissing", "yes");
