@@ -23,7 +23,8 @@ import java.util.HashMap;
 import java.util.Iterator;
 import java.util.Map;
 
-import org.dbdoclet.log.Logger;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import org.dbdoclet.service.StringServices;
 import org.dbdoclet.xiphias.XmlServices;
 import org.w3c.dom.DOMException;
@@ -52,7 +53,7 @@ public class NodeImpl implements Node {
 	public static final short XML_DECLARATION = 23;
 	private static int flavour = XML;
 
-	private static Logger logger = Logger.getLogger(NodeImpl.class);
+	private static Log logger = LogFactory.getLog(NodeImpl.class);
 	private static final String LSEP = System.getProperty("line.separator");
 
 	private NodeListImpl childNodes = new NodeListImpl();
@@ -71,17 +72,14 @@ public class NodeImpl implements Node {
 	private int column;
 	private int line;
 
+	protected boolean isCaseInsensitive = false;
+
 	public NodeImpl() {
 		super();
 	}
 
 	public NodeImpl(String name) {
-
-		if (name != null) {
-			nodeName = name;
-		}
-
-		parent = null;
+		this(name, null);
 	}
 
 	public NodeImpl(String name, NodeImpl parent) {
@@ -90,11 +88,16 @@ public class NodeImpl implements Node {
 			nodeName = name;
 		}
 
+		if (isCaseInsensitive) {
+			nodeName = nodeName.toLowerCase();
+		}
+
 		this.parent = parent;
 	}
 
 	/**
-	 * The method <code>findParent</code> tries to find the nearest parent, which is of type <code>parentClass</code>.
+	 * The method <code>findParent</code> tries to find the nearest parent,
+	 * which is of type <code>parentClass</code>.
 	 * 
 	 * If no parent of this type can be found <code>null</code> is returned.
 	 * 
@@ -200,14 +203,15 @@ public class NodeImpl implements Node {
 		}
 	}
 
-	public static void traverse(Node node, INodeVisitor visitor) throws Exception {
+	public static void traverse(Node node, INodeVisitor visitor)
+			throws Exception {
 
 		if (node != null) {
 
 			if (node instanceof Document) {
 				node = ((Document) node).getDocumentElement();
 			}
-			
+
 			if (visitor != null) {
 				visitor.accept(node);
 			}
@@ -220,6 +224,7 @@ public class NodeImpl implements Node {
 		}
 	}
 
+	@Override
 	public Node appendChild(Node newChild) throws DOMException {
 
 		if (newChild instanceof NodeImpl) {
@@ -232,8 +237,8 @@ public class NodeImpl implements Node {
 	/**
 	 * The method <code>appendChild</code> adds a child node to this node.
 	 * 
-	 * The parent of the child node is explicitly set to this node to this node to avoid inconsistencies in the
-	 * resulting document tree.
+	 * The parent of the child node is explicitly set to this node to this node
+	 * to avoid inconsistencies in the resulting document tree.
 	 * 
 	 * @param node
 	 *            The child node {@link NodeImpl (Node)}.
@@ -281,17 +286,19 @@ public class NodeImpl implements Node {
 		return this;
 	}
 
+	@Override
 	public Node cloneNode(boolean deep) {
 		System.err.println("Not yet implemented");
 		return null;
 	}
 
+	@Override
 	public short compareDocumentPosition(Node other) throws DOMException {
 		System.err.println("Not yet implemented");
 		return 0;
 	}
 
-	public ElementImpl findChildElement(String tagName) {
+	public NodeImpl findChildElement(String tagName) {
 
 		if (tagName == null) {
 			throw new IllegalArgumentException(
@@ -313,7 +320,7 @@ public class NodeImpl implements Node {
 				nodeName = element.getNodeName();
 
 				if (nodeName != null && nodeName.equals(tagName)) {
-					return (ElementImpl) element;
+					return element;
 				}
 			}
 		}
@@ -327,6 +334,7 @@ public class NodeImpl implements Node {
 		return findParent(parent, parentClass);
 	}
 
+	@Override
 	public NamedNodeMap getAttributes() {
 
 		if (this instanceof Element) {
@@ -335,6 +343,7 @@ public class NodeImpl implements Node {
 		return null;
 	}
 
+	@Override
 	public String getBaseURI() {
 		System.err.println("Not yet implemented");
 		return null;
@@ -358,10 +367,12 @@ public class NodeImpl implements Node {
 	}
 
 	/**
-	 * The method <code>getChildNodes</code> returns a list with all children of this node..
+	 * The method <code>getChildNodes</code> returns a list with all children of
+	 * this node..
 	 * 
 	 * @return an <code>ArrayList</code> value
 	 */
+	@Override
 	public NodeList getChildNodes() {
 
 		if (childNodes == null) {
@@ -400,18 +411,21 @@ public class NodeImpl implements Node {
 		return list;
 	}
 
+	@Override
 	public Object getFeature(String feature, String version) {
 		System.err.println("Not yet implemented");
 		return null;
 	}
 
 	/**
-	 * The method <code>getFirstChild</code> returns the first child of this node.
+	 * The method <code>getFirstChild</code> returns the first child of this
+	 * node.
 	 * 
 	 * If this node has no children, <code>null</code> is returned.
 	 * 
 	 * @return a <code>Node</code> value
 	 */
+	@Override
 	public NodeImpl getFirstChild() {
 
 		if (childNodes == null || childNodes.size() < 1) {
@@ -422,14 +436,14 @@ public class NodeImpl implements Node {
 	}
 
 	/**
-	 * The method <code>getFirstElement</code> returns the first child of this node that is of type
-	 * <code>ELEMENT_NODE</code>.
+	 * The method <code>getFirstElement</code> returns the first child of this
+	 * node that is of type <code>ELEMENT_NODE</code>.
 	 * 
 	 * If this node has no element child, <code>null</code> is returned.
 	 * 
 	 * @return The element or null, if element child can be found.
 	 */
-	public NodeImpl getFirstElement() {
+	public Element getFirstElement() {
 
 		if ((childNodes == null) || (childNodes.size() < 1)) {
 			return null;
@@ -445,7 +459,7 @@ public class NodeImpl implements Node {
 			}
 		}
 
-		return element;
+		return (Element) element;
 	}
 
 	/* ========================================================== */
@@ -456,9 +470,14 @@ public class NodeImpl implements Node {
 		return flavour;
 	}
 
+	@Override
 	public Node getLastChild() {
-		System.err.println("Not yet implemented");
-		return null;
+
+		if (childNodes == null || childNodes.size() == 0) {
+			return null;
+		}
+
+		return childNodes.get(childNodes.size() - 1);
 	}
 
 	public NodeImpl getLastChild(Class<? extends NodeImpl> type) {
@@ -495,6 +514,7 @@ public class NodeImpl implements Node {
 		return line;
 	}
 
+	@Override
 	public String getLocalName() {
 
 		if (this instanceof ElementImpl || this instanceof AttrImpl
@@ -512,10 +532,12 @@ public class NodeImpl implements Node {
 		return null;
 	}
 
+	@Override
 	public String getNamespaceURI() {
 		return namespaceUri;
 	}
 
+	@Override
 	public Node getNextSibling() {
 		NodeImpl parent = getTrafoParentNode();
 
@@ -542,14 +564,17 @@ public class NodeImpl implements Node {
 		return null;
 	}
 
+	@Override
 	public String getNodeName() {
 		return nodeName;
 	}
 
+	@Override
 	public short getNodeType() {
 		return nodeType;
 	}
 
+	@Override
 	public String getNodeValue() throws DOMException {
 		return nodeValue;
 	}
@@ -558,15 +583,18 @@ public class NodeImpl implements Node {
 		return childNodes.size();
 	}
 
+	@Override
 	public Document getOwnerDocument() {
 		System.err.println("Not yet implemented");
 		return null;
 	}
 
+	@Override
 	public Node getParentNode() {
 		return parent;
 	}
 
+	@Override
 	public String getPrefix() {
 
 		if (this instanceof ElementImpl || this instanceof AttrImpl) {
@@ -583,6 +611,7 @@ public class NodeImpl implements Node {
 		return null;
 	}
 
+	@Override
 	public Node getPreviousSibling() {
 
 		NodeImpl parent = getTrafoParentNode();
@@ -632,6 +661,7 @@ public class NodeImpl implements Node {
 		return (NodeImpl) root;
 	}
 
+	@Override
 	public String getTextContent() {
 		return NodeImpl.getTextContent(this);
 	}
@@ -662,6 +692,7 @@ public class NodeImpl implements Node {
 		return transformInstruction;
 	}
 
+	@Override
 	public Object getUserData(String key) {
 
 		if (key == null || userDataMap == null) {
@@ -684,16 +715,19 @@ public class NodeImpl implements Node {
 		return buffer;
 	}
 
+	@Override
 	public boolean hasAttributes() {
 		System.err.println("Not yet implemented");
 		return false;
 	}
 
 	/**
-	 * The method <code>hasChildren</code> returns true, if the node contains any children.
+	 * The method <code>hasChildren</code> returns true, if the node contains
+	 * any children.
 	 * 
 	 * @return an <code>int</code> value
 	 */
+	@Override
 	public boolean hasChildNodes() {
 
 		if (childNodes == null) {
@@ -710,7 +744,8 @@ public class NodeImpl implements Node {
 	}
 
 	/**
-	 * The method <code>hasElementChildren</code> returns true, if the node contains any children, which are elements.
+	 * The method <code>hasElementChildren</code> returns true, if the node
+	 * contains any children, which are elements.
 	 * 
 	 * @return an <code>int</code> value
 	 */
@@ -737,7 +772,7 @@ public class NodeImpl implements Node {
 	public boolean hasSiblingElements() {
 
 		NodeImpl parent = (NodeImpl) getParentNode();
-		
+
 		if (parent == null) {
 			return false;
 		}
@@ -768,7 +803,7 @@ public class NodeImpl implements Node {
 		return false;
 	}
 
-	public NodeImpl insertAfter(NodeImpl newChild, NodeImpl refChild) {
+	public NodeImpl insertAfter(Node newChild, Node refChild) {
 
 		if (newChild == null) {
 			throw new IllegalArgumentException(
@@ -796,14 +831,16 @@ public class NodeImpl implements Node {
 
 			if (index > -1) {
 
-				newChild.setParentNode(this);
-				childNodes.add(index + 1, newChild);
+				NodeImpl newChildImpl = (NodeImpl) newChild;
+				newChildImpl.setParentNode(this);
+				childNodes.add(index + 1, newChildImpl);
 			}
 		}
 
 		return this;
 	}
 
+	@Override
 	public Node insertBefore(Node newChild, Node refChild) throws DOMException {
 
 		NodeListImpl childList = (NodeListImpl) getChildNodes();
@@ -827,7 +864,8 @@ public class NodeImpl implements Node {
 	}
 
 	/**
-	 * The method <code>insertChild</code> inserts a child node at the specified index.
+	 * The method <code>insertChild</code> inserts a child node at the specified
+	 * index.
 	 * 
 	 * @param index
 	 *            an <code>int</code> value
@@ -843,6 +881,7 @@ public class NodeImpl implements Node {
 		return this;
 	}
 
+	@Override
 	public boolean isDefaultNamespace(String namespaceURI) {
 		System.err.println("Not yet implemented");
 		return false;
@@ -858,6 +897,7 @@ public class NodeImpl implements Node {
 		return this;
 	}
 
+	@Override
 	public boolean isEqualNode(Node otherNode) {
 		return equals(otherNode);
 	}
@@ -879,7 +919,8 @@ public class NodeImpl implements Node {
 	}
 
 	/**
-	 * The method <code>isRoot</code> returns true if this node is <em>Root</em> node.
+	 * The method <code>isRoot</code> returns true if this node is <em>Root</em>
+	 * node.
 	 * 
 	 * @return a <code>boolean</code> value
 	 */
@@ -892,21 +933,25 @@ public class NodeImpl implements Node {
 		return false;
 	}
 
+	@Override
 	public boolean isSameNode(Node other) {
 		System.err.println("Not yet implemented");
 		return false;
 	}
 
+	@Override
 	public boolean isSupported(String feature, String version) {
 		System.err.println("Not yet implemented");
 		return false;
 	}
 
+	@Override
 	public String lookupNamespaceURI(String prefix) {
 		System.err.println("Not yet implemented");
 		return null;
 	}
 
+	@Override
 	public String lookupPrefix(String namespaceURI) {
 		System.err.println("Not yet implemented");
 		return null;
@@ -923,10 +968,12 @@ public class NodeImpl implements Node {
 		return this;
 	}
 
+	@Override
 	public void normalize() {
 		System.err.println("Not yet implemented");
 	}
 
+	@Override
 	public Node removeChild(Node node) throws DOMException {
 
 		if (node == null) {
@@ -957,10 +1004,12 @@ public class NodeImpl implements Node {
 	/**
 	 * {@inheritDoc}
 	 * 
-	 * The method <code>replaceChild</code> exchanges a node against another one.
+	 * The method <code>replaceChild</code> exchanges a node against another
+	 * one.
 	 * 
-	 * Beware of that the parent of the old child is set to null. If either <code>oldNode</code> or <code>newNode</code>
-	 * is <code>null</code>, an <code>IllegalArgumentException</code> is thrown.
+	 * Beware of that the parent of the old child is set to null. If either
+	 * <code>oldNode</code> or <code>newNode</code> is <code>null</code>, an
+	 * <code>IllegalArgumentException</code> is thrown.
 	 * 
 	 * @param oldChild
 	 *            a <code>Node</code> value
@@ -968,6 +1017,7 @@ public class NodeImpl implements Node {
 	 *            a <code>Node</code> value
 	 * @return a <code>Node</code> value
 	 */
+	@Override
 	public Node replaceChild(Node newChild, Node oldChild) throws DOMException {
 
 		logger.debug("(W3C) Replacing child " + oldChild + " with child "
@@ -1000,8 +1050,8 @@ public class NodeImpl implements Node {
 	}
 
 	/**
-	 * Die Methode <code>setColumn</code> setzt die Spaltennummer in der das Element ursprünglich vom Tokenizer gefunden
-	 * wurde.
+	 * Die Methode <code>setColumn</code> setzt die Spaltennummer in der das
+	 * Element ursprünglich vom Tokenizer gefunden wurde.
 	 * 
 	 * @param column
 	 *            <code>int</code>
@@ -1015,8 +1065,8 @@ public class NodeImpl implements Node {
 	}
 
 	/**
-	 * Die Methode <code>setLine</code> setzt die Zeilennummer in der das Element ursprünglich vom Tokenizer gefunden
-	 * wurde.
+	 * Die Methode <code>setLine</code> setzt die Zeilennummer in der das
+	 * Element ursprünglich vom Tokenizer gefunden wurde.
 	 * 
 	 * @param line
 	 *            <code>int</code>
@@ -1041,6 +1091,7 @@ public class NodeImpl implements Node {
 		this.nodeType = nodeType;
 	}
 
+	@Override
 	public void setNodeValue(String nodeValue) throws DOMException {
 		this.nodeValue = nodeValue;
 	}
@@ -1054,10 +1105,12 @@ public class NodeImpl implements Node {
 		this.parent = parent;
 	}
 
+	@Override
 	public void setPrefix(String prefix) throws DOMException {
 		System.err.println("Not yet implemented");
 	}
 
+	@Override
 	public void setTextContent(String textContent) throws DOMException {
 
 		childNodes.clear();
@@ -1077,6 +1130,7 @@ public class NodeImpl implements Node {
 		this.transformInstruction = transformInstruction;
 	}
 
+	@Override
 	public Object setUserData(String key, Object data, UserDataHandler handler) {
 
 		if (userDataMap == null) {
@@ -1120,19 +1174,19 @@ public class NodeImpl implements Node {
 			buffer.append(nodeName);
 			buffer.append(' ');
 		}
-		
+
 		if (nodeValue != null) {
 			buffer.append("value=");
 			buffer.append(nodeValue);
-			buffer.append(' ');			
+			buffer.append(' ');
 		}
-		
+
 		String text = buffer.toString();
-		
+
 		if (text.length() > 42) {
 			text = text.substring(0, 39) + "...";
 		}
-		
+
 		return text;
 	}
 
@@ -1275,4 +1329,27 @@ public class NodeImpl implements Node {
 		return true;
 	}
 
+	/**
+	 * Falls die Sprache nicht zwischen Groß- und Kleinschreibung unterscheidet,
+	 * muss das Attribute <code>isCaseSensitive</code> auf <code>true</code>
+	 * gesetzt werden.
+	 * 
+	 * <p>
+	 * Die Methode konvertiert bereits bestehende Daten in Kleinbuchstaben.
+	 * Sollten dabei Doppeldeutigkeiten auftreten, gilt der letzte, verarbeitete
+	 * Wert.
+	 * 
+	 * @param isCaseInsensitive
+	 * @return NodeImpl
+	 */
+	public NodeImpl isCaseInsensitive(boolean isCaseInsensitive) {
+		this.isCaseInsensitive = isCaseInsensitive;
+
+		if (nodeName != null) {
+			nodeName = nodeName.toLowerCase();
+		}
+
+		return this;
+	}
+
 }
